@@ -8,10 +8,10 @@
 
 
 class ViewConfig(object):
-    '''Defines the configuration for a View object.'''
+    """Defines the configuration for a View object."""
 
     def __init__(self, **config):
-        '''Receives a user-provided config dict and standardizes it for
+        """Receives a user-provided config dict and standardizes it for
         reference.
 
         Keyword Arguments:
@@ -31,58 +31,58 @@ class ViewConfig(object):
             filter (:obj:`list` of :obj:`list` of :obj:`str`):  A list of lists,
                 each list containing a column name, a filter comparator, and a
                 value to filter by.
-        '''
+        """
         self._config = config
-        self._row_pivots = self._config.get('row_pivots', [])
-        self._column_pivots = self._config.get('column_pivots', [])
-        self._aggregates = self._config.get('aggregates', {})
-        self._columns = self._config.get('columns', [])
-        self._sort = self._config.get('sort', [])
-        self._filter = self._config.get('filter', [])
-        self._computed_columns = self._config.get('computed_columns', [])
-        self._filter_op = self._config.get('filter_op', "and")
+        self._row_pivots = self._config.get("row_pivots", [])
+        self._column_pivots = self._config.get("column_pivots", [])
+        self._aggregates = self._config.get("aggregates", {})
+        self._columns = self._config.get("columns", [])
+        self._sort = self._config.get("sort", [])
+        self._filter = self._config.get("filter", [])
+        self._computed_columns = self._config.get("computed_columns", [])
+        self._filter_op = self._config.get("filter_op", "and")
         self.row_pivot_depth = self._config.get("row_pivot_depth", None)
         self.column_pivot_depth = self._config.get("column_pivot_depth", None)
 
     def get_row_pivots(self):
-        '''The columns used as
+        """The columns used as
         [row pivots](https://en.wikipedia.org/wiki/Pivot_table#Row_labels)
 
         Returns:
             list : the columns used as row pivots
-        '''
+        """
         return self._row_pivots
 
     def get_column_pivots(self):
-        '''The columns used as
+        """The columns used as
         [column pivots](https://en.wikipedia.org/wiki/Pivot_table#Column_labels)
 
         Returns:
             list : the columns used as column pivots
-        '''
+        """
         return self._column_pivots
 
     def get_aggregates(self):
-        '''Defines the grouping of data within columns.
+        """Defines the grouping of data within columns.
 
         Returns:
             dict[str:str]  a vector of string vectors in which the first value
                 is the column name, and the second value is the string
                 representation of an aggregate
-        '''
+        """
         return self._aggregates
 
     def get_columns(self):
-        '''The columns that will be shown to the user in the view. If left
+        """The columns that will be shown to the user in the view. If left
         empty, the view shows all columns in the dataset by default.
 
         Returns:
             `list` : the columns shown to the user
-        '''
+        """
         return self._columns
 
     def get_sort(self):
-        '''The columns that should be sorted, and the direction to sort.
+        """The columns that should be sorted, and the direction to sort.
 
         A sort configuration is a `list` of two elements: a string column name,
         and a string sort direction, which are:  "none", "asc", "desc",
@@ -92,14 +92,14 @@ class ViewConfig(object):
         Returns:
             `list`: the sort configurations of the view stored in a `list` of
                 `list`s
-        '''
+        """
         return self._sort
 
     def get_computed_columns(self):
         return self._computed_columns
 
     def get_filter(self):
-        '''The columns that should be filtered.
+        """The columns that should be filtered.
 
         A filter configuration is a `list` of three elements:
             0: `str` column name.
@@ -110,11 +110,11 @@ class ViewConfig(object):
         Returns:
             `list`: the filter configurations of the view stored in a `list` of
                 lists
-        '''
+        """
         return self._filter
 
     def get_filter_op(self):
-        '''When multiple filters are applied, filter_op defines how data should
+        """When multiple filters are applied, filter_op defines how data should
         be returned.
 
         Defaults to "and" if not set by the user, meaning that data returned
@@ -123,9 +123,9 @@ class ViewConfig(object):
 
         Returns:
             `str`: the filter_op of the view
-        '''
+        """
         return self._filter_op
 
     def get_config(self):
-        '''Returns the original dictionary config passed by the user.'''
+        """Returns the original dictionary config passed by the user."""
         return self._config
